pub enum AssetLocation {
LocalFile(LocalFileLocator),
Package(PackageLocator),
}Expand description
Describes the location of a font asset (excluding its file name).
Variants
LocalFile(LocalFileLocator)
Indicates that the file is accessible through a file path in the font server’s namespace
(e.g. at /config/data/fonts/).
Package(PackageLocator)
Indicates that the file is accessible in a separate font package (e.g.
fuchsia-pkg://fuchsia.com/font-package-roboto-regular-ttf).